@@ -142,6 +142,10 @@ def graphWave(G, g=None, ts=None, nodes=None, ecf_method=None, **kwargs):
     G.gw = gw
     return gw
 
+def gw_flatten(gw):
+    data_z = gw.reshape(gw.shape[0], gw.shape[1]*gw.shape[2])
+    return np.c_[data_z.real, data_z.imag]
+
 def spectrogram(G, g=None, M=100, shifts=None, nodes=None, **kwargs):
     if g is None:
         g = GaussianFilter(G, M)
@@ -166,19 +170,30 @@ def kernelCentrality(G, g=None, nodes=None, **kwargs):
     G.centr = centr
     return centr
 
-def plotTig(tig):
+def plotTig(tig, nodes=None):
     if isinstance(tig, gsp.filters.Filter):
         g = tig
         tig = _tig(g, createSignal(g.G))
 
-    fig, axs = plt.subplots(tig.shape[0], tig.shape[2], sharex='col', sharey='col')
+    if nodes is None:
+        nodes = range(tig.shape[0])
+    elif not hasattr(nodes, '__iter__'):
+        nodes = [nodes]
+
+    num_nodes = len(nodes)
+    num_filters = tig.shape[2]
+    fig, axs = plt.subplots(num_nodes, num_filters, sharex='col', sharey='col')
     fig.suptitle('{} wavelet coefficients'.format(g.__class__.__name__))
-    for n in range(tig.shape[0]):
-        for f in range(tig.shape[2]):
-            if tig.shape[2] > 1:
-                axs[n][f].plot(tig[n,:,f])
+    for i, n in enumerate(nodes):
+        for f in range(num_filters):
+            if num_nodes > 1 and num_filters > 1:
+                axs[i][f].plot(tig[n,:,f])
+            elif num_nodes == 1 and num_filters > 1:
+                axs[f].plot(tig[n,:,f])
+            elif num_nodes > 1 and num_filters == 1:
+                axs[i].plot(tig[n,:,f])
             else:
-                axs[n].plot(tig[n,:,f])
+                axs.plot(tig[n,:,f])
     fig.show()
     return fig
 
@@ -506,6 +521,10 @@ class BipartiteGraph(BigGraph):
         if self.lap_type == 'normalized':
             assert self.e[-1] == 2
 
+class StarGraph(gsp.graphs.Comet):
+    def __init__(self, N):
+        super().__init__(N, N-1)
+
 class GWHeat(gsp.filters.Filter):
     """
     Heat kernel used by GraphWave.
